@@ -95,9 +95,25 @@ class HMACTest(TransactionTestCase):
     def setUp(self):
         self.api_key = APIKey.objects.create(email="test@example.com")
 
-    def test_paramater_sign(self):
+    def test_parameter_sign(self):
+        # test unicode
         url_params = u'first_name=mårten&last_name=superkebab'
         dict_params = {'first_name': u'mårten', 'last_name': u'superkebab'}
+        self.assert_equal_signs(url_params, dict_params)
+        # test string
+        url_params = 'first_name=mårten&last_name=superkebab'
+        dict_params = {'first_name': 'mårten', 'last_name': 'superkebab'}
+        self.assert_equal_signs(url_params, dict_params)
+        # test integer
+        url_params = u'dividend=4&divisor=2'
+        dict_params = {'dividend': 4, 'divisor': 2}
+        self.assert_equal_signs(url_params, dict_params)
+        # test boolean
+        url_params = u'secure=True'
+        dict_params = {'secure': True}
+        self.assert_equal_signs(url_params, dict_params)
+
+    def assert_equal_signs(self, url_params, dict_params):
         sign1 = get_sign(self.api_key.secret, querystring=url_params)
         sign2 = get_sign(self.api_key.secret, **dict_params)
         self.assertEqual(sign1, sign2)
